@@ -183,7 +183,7 @@ def get_ligand_rings(sm, start_idx=0):
         aromatics = sum([sm._mol.GetAtomWithIdx(idx).GetIsAromatic() for idx in ring])
         if aromatics != len(ring):
             continue
-        ligandAtomAromaticRings.append([r + start_idx for r in ring])
+        ligandAtomAromaticRings.append(tuple([r + start_idx for r in ring]))
     return ligandAtomAromaticRings
 
 
@@ -272,7 +272,7 @@ def hbonds_calculate(
 
     hbond_list = []
     for f in range(mol.numFrames):
-        hbond_list.append(np.array(hb[f]).reshape(-1, 3))
+        hbond_list.append([hb[f][i : i + 3] for i in range(0, len(hb[f]), 3)])
     return hbond_list
 
 
@@ -320,6 +320,7 @@ def waterbridge_calculate(
         curr_shell = hbonds_calculate(sel1=sel1_b_curr, sel2=water_goal, **args)
         for f in range(mol.numFrames):
             # Only keep interactions which have at least one water
+            curr_shell[f] = np.array(curr_shell[f])
             has_water = np.any(np.isin(curr_shell[f], water_idx), axis=1)
             curr_shell[f] = curr_shell[f][has_water, :]
             # Append the valid edges for this frame
@@ -376,14 +377,21 @@ def pipi_calculate(
     rings1,
     rings2,
     dist_threshold1=4.4,
-    angle_threshold1_min=0,
     angle_threshold1_max=30,
     dist_threshold2=5.5,
     angle_threshold2_min=60,
-    angle_threshold2_max=120,
+    return_rings=False,
 ):
     from moleculekit.interactions import pipi
 
+    if (
+        angle_threshold1_max < 0
+        or angle_threshold1_max > 90
+        or angle_threshold2_min < 0
+        or angle_threshold2_min > 90
+    ):
+        raise RuntimeError("Values for angles should be [0, 90] degrees")
+
     if len(rings1) == 0 or len(rings2) == 0:
         return [[] for _ in range(mol.numFrames)], [[] for _ in range(mol.numFrames)]
 
@@ -399,18 +407,20 @@ def pipi_calculate(
         mol.coords,
         mol.box,
         dist_threshold1=dist_threshold1,
-        angle_threshold1_min=angle_threshold1_min,
         angle_threshold1_max=angle_threshold1_max,
         dist_threshold2=dist_threshold2,
         angle_threshold2_min=angle_threshold2_min,
-        angle_threshold2_max=angle_threshold2_max,
     )
 
     pp_list = []
     dist_ang_list = []
     for f in range(mol.numFrames):
-        pp_list.append(np.array(pp[f]).reshape(-1, 2))
-        dist_ang_list.append(np.array(da[f]).reshape(-1, 2))
+        reshaped = [pp[f][i : i + 2] for i in range(0, len(pp[f]), 2)]
+        if return_rings:
+            pp_list.append([[rings1[pp[0]], rings2[pp[1]]] for pp in reshaped])
+        else:
+            pp_list.append(reshaped)
+        dist_ang_list.append([da[f][i : i + 2] for i in range(0, len(da[f]), 2)])
     return pp_list, dist_ang_list
 
 
@@ -461,10 +471,13 @@ def cationpi_calculate(
     cations,
     dist_threshold=5,
     angle_threshold_min=60,
-    angle_threshold_max=120,
+    return_rings=False,
 ):
     from moleculekit.interactions import cationpi
 
+    if angle_threshold_min < 0 or angle_threshold_min > 90:
+        raise RuntimeError("Values for angles should be [0, 90] degrees")
+
     if len(rings) == 0 or len(cations) == 0:
         return [[] for _ in range(mol.numFrames)], [[] for _ in range(mol.numFrames)]
 
@@ -479,14 +492,17 @@ def cationpi_calculate(
         mol.box,
         dist_threshold=dist_threshold,
         angle_threshold_min=angle_threshold_min,
-        angle_threshold_max=angle_threshold_max,
     )
 
     index_list = []
     dist_ang_list = []
     for f in range(mol.numFrames):
-        index_list.append(np.array(pp[f], dtype=np.int64).reshape(-1, 2))
-        dist_ang_list.append(np.array(da[f], dtype=np.float64).reshape(-1, 2))
+        reshaped = [pp[f][i : i + 2] for i in range(0, len(pp[f]), 2)]
+        if return_rings:
+            index_list.append([[rings[pp[0]], pp[1]] for pp in reshaped])
+        else:
+            index_list.append(reshaped)
+        dist_ang_list.append([da[f][i : i + 2] for i in range(0, len(da[f]), 2)])
     return index_list, dist_ang_list
 
 
@@ -496,10 +512,13 @@ def sigmahole_calculate(
     halides,
     dist_threshold=4.5,
     angle_threshold_min=60,
-    angle_threshold_max=120,
+    return_rings=False,
 ):
     from moleculekit.interactions import sigmahole
 
+    if angle_threshold_min < 0 or angle_threshold_min > 90:
+        raise RuntimeError("Values for angles should be [0, 90] degrees")
+
     if len(rings) == 0 or len(halides) == 0:
         return [[] for _ in range(mol.numFrames)], [[] for _ in range(mol.numFrames)]
 
@@ -514,14 +533,17 @@ def sigmahole_calculate(
         mol.box,
         dist_threshold=dist_threshold,
         angle_threshold_min=angle_threshold_min,
-        angle_threshold_max=angle_threshold_max,
     )
 
     index_list = []
     dist_ang_list = []
     for f in range(mol.numFrames):
-        index_list.append(np.array(indexes[f]).reshape(-1, 2))
-        dist_ang_list.append(np.array(da[f]).reshape(-1, 2))
+        reshaped = [indexes[f][i : i + 2] for i in range(0, len(indexes[f]), 2)]
+        if return_rings:
+            index_list.append([[rings[pp[0]], pp[1]] for pp in reshaped])
+        else:
+            index_list.append(reshaped)
+        dist_ang_list.append([da[f][i : i + 2] for i in range(0, len(da[f]), 2)])
     return index_list, dist_ang_list
 
 
@@ -563,7 +585,7 @@ class _TestInteractions(unittest.TestCase):
 
         hb = hbonds_calculate(mol, donors, acceptors, "all")
         assert len(hb) == 2
-        assert hb[0].shape == (178, 3), hb[0].shape
+        assert np.array(hb[0]).shape == (178, 3), np.array(hb[0]).shape
 
     def test_pipi(self):
         from moleculekit.home import home
@@ -588,13 +610,39 @@ class _TestInteractions(unittest.TestCase):
 
         ref_distang = np.array(
             [
-                [5.33927107, 97.67315674],
+                [5.33927107, 82.32684326],
                 [5.23078251, 85.32985687],
                 [5.16490269, 81.33213806],
             ]
         )
         assert np.allclose(distang[0], ref_distang)
 
+        mol = Molecule(os.path.join(home(dataDir="test-interactions"), "6dn1.pdb"))
+        lig = SmallMol(
+            os.path.join(home(dataDir="test-interactions"), "6dn1_ligand-RDK.sdf")
+        )
+
+        lig_idx = np.where(mol.resname == "MOL")[0][0]
+
+        prot_rings = get_nucleic_rings(mol)
+        lig_rings = get_ligand_rings(lig, start_idx=lig_idx)
+
+        pipis, distang = pipi_calculate(mol, prot_rings, lig_rings)
+
+        assert len(pipis) == 1
+
+        ref_rings = np.array([[72, 2], [73, 1], [74, 1]])
+        assert np.array_equal(pipis[0], ref_rings)
+
+        ref_distang = np.array(
+            [
+                [4.1462903, 22.34738922],
+                [3.52108073, 11.22733593],
+                [4.05929375, 4.60079527],
+            ]
+        )
+        assert np.allclose(distang[0], ref_distang)
+
     def test_salt_bridge(self):
         from moleculekit.home import home
         from moleculekit.molecule import Molecule
