@@ -64,8 +64,9 @@ def getRCSBLigandByLigname(ligname, returnMol2=False):
     from moleculekit.support import string_to_tempfile
     from moleculekit.smallmol.smallmol import SmallMol
     from moleculekit.rcsb import _getRCSBtext
+    from moleculekit.tools.obabel_tools import openbabelConvert
 
-    url = "https://files.rcsb.org/ligands/view/{}_ideal.sdf".format(ligname)
+    url = f"https://files.rcsb.org/ligands/view/{ligname}_ideal.sdf"
     sdf_text = _getRCSBtext(url).decode("ascii")
     tempfile = string_to_tempfile(sdf_text, "sdf")
     mol2 = openbabelConvert(tempfile, "sdf", "mol2")
@@ -79,33 +80,33 @@ def getRCSBLigandByLigname(ligname, returnMol2=False):
 
 def getChemblLigandByDrugName(drugname, returnSmile=False):
     """
-        Returns a SmallMol object of a ligand by its drug name. This molecule is retrieve from Chembl. It is possible to
-        return also the smile of the ligand.
+    Returns a SmallMol object of a ligand by its drug name. This molecule is retrieve from Chembl. It is possible to
+    return also the smile of the ligand.
 
-        Parameters
-        ----------
-        drugname: str
-            The drug name
-        returnSmile: bool
-            If True, the smile is returned
+    Parameters
+    ----------
+    drugname: str
+        The drug name
+    returnSmile: bool
+        If True, the smile is returned
 
-        Returns
-        -------
-        sm: moleculekit.smallmol.smallmol.SmallMol
-            The SmallMol object
+    Returns
+    -------
+    sm: moleculekit.smallmol.smallmol.SmallMol
+        The SmallMol object
 
-        smile: str
-            The smile
+    smile: str
+        The smile
 
-        Example
-        -------
-        >>> sm = getChemblLigandByDrugName('paracetamol')  # doctest: +SKIP
-        >>> sm.numAtoms  # doctest: +SKIP
-        20
-        >>> sm, smile = getChemblLigandByDrugName('paracetamol', returnSmile=True)  # doctest: +SKIP
-        >>> smile  # doctest: +SKIP
-        'CC(=O)Nc1ccc(O)cc1'
-        """
+    Example
+    -------
+    >>> sm = getChemblLigandByDrugName('paracetamol')  # doctest: +SKIP
+    >>> sm.numAtoms  # doctest: +SKIP
+    20
+    >>> sm, smile = getChemblLigandByDrugName('paracetamol', returnSmile=True)  # doctest: +SKIP
+    >>> smile  # doctest: +SKIP
+    'CC(=O)Nc1ccc(O)cc1'
+    """
     from moleculekit.smallmol.smallmol import SmallMol
 
     try:
@@ -144,36 +145,36 @@ def getChemblLigandByDrugName(drugname, returnSmile=False):
 
 def getChemblSimilarLigandsBySmile(smi, threshold=85, returnSmiles=False):
     """
-        Returns a SmallMolLib object of the ligands having a similarity with a smile of at least the specified
-        threshold.. This molecules are retrieve from Chembl. It is possible to return also the list smiles.
+    Returns a SmallMolLib object of the ligands having a similarity with a smile of at least the specified
+    threshold.. This molecules are retrieve from Chembl. It is possible to return also the list smiles.
 
-        Parameters
-        ----------
-        smi: str
-            The smile
-        threshold: int
-            The threshold value to apply for the similarity search
-        returnSmiles: bool
-            If True, the list smiles is returned
+    Parameters
+    ----------
+    smi: str
+        The smile
+    threshold: int
+        The threshold value to apply for the similarity search
+    returnSmiles: bool
+        If True, the list smiles is returned
 
-        Returns
-        -------
-        sm: moleculekit.smallmol.smallmol.SmallMol
-            The SmallMol object
+    Returns
+    -------
+    sm: moleculekit.smallmol.smallmol.SmallMol
+        The SmallMol object
 
-        smiles: str
-            The list of smiles
+    smiles: str
+        The list of smiles
 
-        Example
-        -------
-        >>> _, smile = getChemblLigandByDrugName('ibuprofen', returnSmile=True)  # doctest: +SKIP
-        >>> lib = getChemblSimilarLigandsBySmile(smile)  # doctest: +SKIP
-        >>> lib.numMols  # doctest: +SKIP
-        4
-        >>> lib, smiles = getChemblSimilarLigandsBySmile(smile, returnSmiles=True)  # doctest: +SKIP
-        >>> len(smiles)  # doctest: +SKIP
-        4
-        """
+    Example
+    -------
+    >>> _, smile = getChemblLigandByDrugName('ibuprofen', returnSmile=True)  # doctest: +SKIP
+    >>> lib = getChemblSimilarLigandsBySmile(smile)  # doctest: +SKIP
+    >>> lib.numMols  # doctest: +SKIP
+    4
+    >>> lib, smiles = getChemblSimilarLigandsBySmile(smile, returnSmiles=True)  # doctest: +SKIP
+    >>> len(smiles)  # doctest: +SKIP
+    4
+    """
     from moleculekit.smallmol.smallmol import SmallMol
     from moleculekit.smallmol.smallmollib import SmallMolLib
 
@@ -211,43 +212,6 @@ def getChemblSimilarLigandsBySmile(smi, threshold=85, returnSmiles=False):
     return lib
 
 
-def openbabelConvert(input_file, input_format, output_format):
-    """
-    Converts the file from the input format to the output format specified. It uses the openbabel features
-
-    Parameters
-    ----------
-    input_file: str
-        The path of the input file to convert
-    input_format: str
-        The input file format
-    output_format: str
-        The output file format
-
-    Returns
-    -------
-    outfile: str
-        The output file generated
-    """
-
-    from openbabel import openbabel
-    import tempfile
-
-    input_format = input_format[1:] if input_format.startswith(".") else input_format
-
-    file = tempfile.NamedTemporaryFile(delete=True, suffix="." + output_format)
-    file.close()
-    outfile = file.name
-
-    _ = openbabel.OBConversion()
-    _.SetInAndOutFormats(input_format, output_format)
-    _mol = openbabel.OBMol()
-    _.ReadFile(_mol, input_file)
-    _.WriteFile(_mol, outfile)
-
-    return outfile
-
-
 def convertToString(arr):
 
     if isinstance(arr, list):
@@ -301,15 +265,11 @@ def _depictMol(
         )
 
     ext = ".svg"
-
     if filename is not None:
-        fileext = splitext(filename)[-1]
-
-        if fileext == "":
+        ext = splitext(filename)[-1]
+        if ext == "":
             ext = ".svg"
             filename = filename + ".svg"
-        else:
-            ext = fileext
 
     # init the drawer object
     if ext == ".png":
@@ -328,26 +288,22 @@ def _depictMol(
         for n, a in enumerate(atomlabels):
             opts.atomLabels[n] = a
 
-    # draw molecule
-    sel_atoms = []
-    sel_colors = {}
     # highlight atoms
+    sel_colors = {}
     if highlightAtoms is not None:
-        if isinstance(highlightAtoms[0], list):
-            sel_atoms = [aIdx for subset in highlightAtoms for aIdx in subset]
-            sel_colors = {
-                aIdx: _highlight_colors[n % len(_highlight_colors)]
-                for n, subset in enumerate(highlightAtoms)
-                for aIdx in subset
-            }
-        else:
-            sel_atoms = highlightAtoms
-            sel_colors = {aIdx: _highlight_colors[0] for aIdx in sel_atoms}
+        if not isinstance(highlightAtoms[0], list):
+            highlightAtoms = [highlightAtoms]
+
+        for n, subset in enumerate(highlightAtoms):
+            for aIdx in subset:
+                if aIdx not in sel_colors:
+                    sel_colors[aIdx] = []
+                sel_colors[aIdx].append(_highlight_colors[n % len(_highlight_colors)])
 
     Kekulize(mol)
-    drawer.DrawMolecule(
-        mol, highlightAtoms=sel_atoms, highlightBonds=[], highlightAtomColors=sel_colors
-    )
+    if np.any([len(sel_colors[aIdx]) > 1 for aIdx in sel_colors]):
+        drawer.drawOptions().fillHighlights = False
+    drawer.DrawMoleculeWithHighlights(mol, "", sel_colors, {}, {}, {}, -1)
     drawer.FinishDrawing()
 
     # svg object
@@ -379,29 +335,29 @@ def depictMultipleMols(
     mols_perrow=3,
 ):
     """
-        Returns the image or the ipython rendering.
+    Returns the image or the ipython rendering.
 
-        Parameters
-        ----------
-        mols_list: list
-            The list of the rdkit molecules to depict
-        filename: str
-            The filename of the image
-        ipython: bool
-            If True, the SVG rendering for jupiter-nootebook are returned
-        legends: list
-            List of titles subfigure for each molecule
-        highlightAtoms: list
-            List of list of atom index to highlight.
-        mols_perrow: int
-            The number of subfigures per row
+    Parameters
+    ----------
+    mols_list: list
+        The list of the rdkit molecules to depict
+    filename: str
+        The filename of the image
+    ipython: bool
+        If True, the SVG rendering for jupiter-nootebook are returned
+    legends: list
+        List of titles subfigure for each molecule
+    highlightAtoms: list
+        List of list of atom index to highlight.
+    mols_perrow: int
+        The number of subfigures per row
 
-        Returns
-        -------
-        svg: SVG
-            If ipython set as True, the SVG rendering is returned
+    Returns
+    -------
+    svg: SVG
+        If ipython set as True, the SVG rendering is returned
 
-        """
+    """
     import rdkit
     from rdkit.Chem.Draw import MolsToGridImage
     from IPython.display import SVG
